connectivity_monitor_plus library
A Flutter package for monitoring network connectivity and internet access.
Classes
- ConnectivityWrapper
- A widget that wraps its child and shows a dialog when there is no internet connectivity.
A Flutter package for monitoring network connectivity and internet access.